ReverseProxyBuilder

Struct ReverseProxyBuilder 

pub struct ReverseProxyBuilder<'a> {
Show 17 fields pub(super) connections: &'a mut Connections, pub(super) upstreams: Vec<(Upstream, Option<usize>, Option<Duration>)>, pub(super) lb_algorithm: LoadBalancerAlgorithm, pub(super) lb_health_check_window: Duration, pub(super) lb_health_check_max_fails: u64, pub(super) lb_health_check: bool, pub(super) lb_retry_connection: bool, pub(super) proxy_no_verification: bool, pub(super) proxy_intercept_errors: bool, pub(super) proxy_http2_only: bool, pub(super) proxy_http2: bool, pub(super) proxy_keepalive: bool, pub(super) proxy_proxy_header: Option<ProxyHeader>, pub(super) proxy_request_header: Vec<(HeaderName, String)>, pub(super) proxy_request_header_replace: Vec<(HeaderName, String)>, pub(super) proxy_request_header_remove: Vec<HeaderName>, pub(super) rewrite_host: bool,
}
Builder for configuring and constructing a ReverseProxy.

Fields

connections: &'a mut Connectionsupstreams: Vec<(Upstream, Option<usize>, Option<Duration>)>lb_algorithm: LoadBalancerAlgorithmlb_health_check_window: Durationlb_health_check_max_fails: u64lb_health_check: boollb_retry_connection: boolproxy_no_verification: boolproxy_intercept_errors: boolproxy_http2_only: boolproxy_http2: boolproxy_keepalive: boolproxy_proxy_header: Option<ProxyHeader>proxy_request_header: Vec<(HeaderName, String)>proxy_request_header_replace: Vec<(HeaderName, String)>proxy_request_header_remove: Vec<HeaderName>rewrite_host: bool

Implementations

Source

impl<'a> ReverseProxyBuilder<'a>

pub fn upstream( self, proxy_to: String, proxy_unix: Option<String>, local_limit: Option<usize>, keepalive_idle_timeout: Option<Duration>, ) -> Self

Adds an upstream backend target.

proxy_to is the backend URL (for example http://127.0.0.1:8080). proxy_unix can be used to target a Unix socket path. local_limit controls per-upstream connection limit. keepalive_idle_timeout sets pooled connection idle timeout.

pub fn upstream_srv( self, to: String, local_limit: Option<usize>, keepalive_idle_timeout: Option<Duration>, secondary_runtime_handle: Handle, dns_servers: Vec<IpAddr>, ) -> Self

Adds a dynamic (SRV-based) upstream backend target.

to is the backend URL (for example http://_http._tcp.example.com). local_limit controls per-upstream connection limit. keepalive_idle_timeout sets pooled connection idle timeout.

pub fn lb_algorithm(self, algorithm: LoadBalancerAlgorithm) -> Self

Sets load balancing algorithm.

pub fn lb_health_check_window(self, window: Duration) -> Self

Sets health-check TTL window for failed backend counters.

pub fn lb_health_check_max_fails(self, max_fails: u64) -> Self

Sets maximum consecutive failed checks before a backend is considered unhealthy.

pub fn lb_health_check(self, enable: bool) -> Self

Enables or disables backend health checks.

pub fn proxy_no_verification(self, no_verification: bool) -> Self

Disables certificate verification for upstream TLS connections.

pub fn proxy_intercept_errors(self, intercept_errors: bool) -> Self

Intercepts upstream errors and converts them to proxy-generated responses.

pub fn lb_retry_connection(self, retry: bool) -> Self

Enables retrying a different backend when connection setup fails.

pub fn proxy_http2_only(self, http2_only: bool) -> Self

Forces HTTP/2-only upstream connections.

pub fn proxy_http2(self, http2: bool) -> Self

Enables HTTP/2 support for upstream connections.

pub fn proxy_keepalive(self, keepalive: bool) -> Self

Enables connection pooling and keepalive reuse.

pub fn proxy_proxy_header(self, proxy_header: Option<ProxyHeader>) -> Self

Sets PROXY protocol header mode for upstream connections.

pub fn proxy_request_header( self, header_name: HeaderName, header_value: String, ) -> Self

Adds a request header to upstream requests.

pub fn proxy_request_header_replace( self, header_name: HeaderName, header_value: String, ) -> Self

Replaces a request header on upstream requests.

pub fn proxy_request_header_remove(self, header_name: HeaderName) -> Self

Removes a request header from upstream requests.

pub fn rewrite_host(self, rewrite_host: bool) -> Self

Enables or disables Host header rewriting for non-HTTPS upstream requests.

pub fn build(self) -> ReverseProxy

Builds a ReverseProxy from the configured options.